@@ -114,14 +114,11 @@ def delete_nanfilled_cols(data, cutoff=.90, exclude=False, inplace=False):
     print(remaining_cols)
 
     if inplace:
-        data.drop(
-            columns=cols_to_delete[cols_to_delete == True].index, inplace=True)
+        data.drop(columns=cols_to_delete[cols_to_delete == True].index, inplace=True)
     else:
-        df = data.drop(
-            columns=cols_to_delete[cols_to_delete == True].index).copy()
+        df = data.drop(columns=cols_to_delete[cols_to_delete == True].index).copy()
         return df
 
-
 def df_description(data, col_count=False, return_only=False):
     """Description des variables enrichie de 2 colonnes = nombre de nan et % de nan
     
